@@ -918,7 +918,7 @@
 #define SOCKOPTLEN_T socklen_t
 
 /* The type of statvfs(2) argument */
-#define WX_STATFS_T struct statfs
+#define WX_STATFS_T struct statvfs
 
 /* The signal handler prototype */
 #define wxTYPE_SA_HANDLER int
@@ -989,13 +989,13 @@
 #define HAVE_UNIX98_PRINTF 1
 
 /* define if you have statfs function */
-#define HAVE_STATFS 1
+/* #undef HAVE_STATFS */
 
 /* define if you have statfs prototype */
-#define HAVE_STATFS_DECL 1
+/* #undef HAVE_STATFS_DECL */
 
 /* define if you have statvfs function */
-/* #undef HAVE_STATVFS */
+#define HAVE_STATVFS 1
 
 /* Define if you have strtoull() and strtoll() */
 #define HAVE_STRTOULL 1
